.. heat-translator documentation master file, created by
   sphinx-quickstart on Tue Jul  9 22:26:36 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to heat-translator's documentation!
===========================================

The heat-translator tool is aimed to translate non-heat templates to OpenStack
Heat Orchestration Template (HOT). Initially the tool is aimed to translate
OASIS Topology and Orchestration Specification for Cloud Applications (TOSCA)
to HOT. However, the tool can be easily extended to support any non-heat
template format to produce HOT.

Contents:
---------

.. toctree::
   :maxdepth: 2

   installation
   usage
   contributing

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
